# ldc-pdf
Adds PDF support to the llm-dataset-converter library.


## Installation

```bash
pip install git+https://github.com/waikato-llm/llm-dataset-converter.git
pip install git+https://github.com/waikato-llm/ldc-pdf.git
```

## Plugins

See [here](plugins/README.md) for an overview of all plugins.
